@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/graphics.c,v 1.32 2006/01/09 16:30:20 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/graphics.c,v 1.34 2006/05/10 14:12:30 richb Exp $
  *
  *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -26,7 +26,7 @@
 #include "extern.h"
 #include "ce_parser.h"
 #include "lr_parser.h"
-
+#include "functions.h"
 
 /* Process menu selection. */
 
@@ -93,7 +93,6 @@ handle_menu_selection(struct button *n, int item)
 void
 make_registers()            /* Calculate memory register frame values. */
 {
-    char line[MAXLINE];     /* Current memory register line. */
     char *mval;
     int n;
 
